pub struct SipHasher(SipHasher24);👎Deprecated since 1.13.0: use
std::hash::DefaultHasher insteadExpand description
An implementation of SipHash 2-4.
See: https://131002.net/siphash/
SipHash is a general-purpose hashing function: it runs at a good
speed (competitive with Spooky and City) and permits strong keyed
hashing. This lets you key your hash tables from a strong RNG, such as
rand::os::OsRng.
Although the SipHash algorithm is considered to be generally strong, it is not intended for cryptographic purposes. As such, all cryptographic uses of this implementation are strongly discouraged.
Tuple Fields
0: SipHasher24👎Deprecated since 1.13.0: use
std::hash::DefaultHasher insteadImplementations
Sourceimpl SipHasher
impl SipHasher
1.0.0 · Sourcepub fn new() -> SipHasher
👎Deprecated since 1.13.0: use std::hash::DefaultHasher instead
pub fn new() -> SipHasher
std::hash::DefaultHasher insteadCreates a new SipHasher with the two initial keys set to 0.
1.0.0 · Sourcepub fn new_with_keys(key0: u64, key1: u64) -> SipHasher
👎Deprecated since 1.13.0: use std::hash::DefaultHasher instead
pub fn new_with_keys(key0: u64, key1: u64) -> SipHasher
std::hash::DefaultHasher insteadCreates a SipHasher that is keyed off the provided keys.